.. _infinite_cartpole:


Infinite Track CartPole: Balance Task
-------------------------------------

.. autoclass:: rlpy.Domains.InfiniteTrackCartPole.InfCartPoleBalance
    :members:
    :inherited-members:


Infinite Track CartPole: Swing-Up Task
--------------------------------------

.. autoclass:: rlpy.Domains.InfiniteTrackCartPole.InfCartPoleSwingUp
    :members:
    :inherited-members:
